美丽人生 (豆瓣)
Description: 美丽人生电影简介和剧情介绍,美丽人生影评、图片、预告片、影讯、论坛、在线购票
Keywords: 美丽人生,La vita è bella,美丽人生影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.6豆瓣电影Top250

# 美丽人生 La vita è bella (1997)

更新描述或海报

导演: 罗伯托·贝尼尼
编剧: 温琴佐·切拉米 / 罗伯托·贝尼尼
主演: 罗伯托·贝尼尼 / 尼可莱塔·布拉斯基 / 乔治·坎塔里尼 / 朱斯蒂诺·杜拉诺 / 赛尔乔·比尼·布斯特里克 / 玛丽萨·帕雷德斯 / 霍斯特·布赫霍尔茨 / 利迪娅·阿方西 / 朱利亚娜·洛约迪切 / 亚美利哥·丰塔尼 / 彼得·德·席尔瓦 / 弗朗西斯·古佐 / 拉法埃拉·莱博罗尼 / 克劳迪奥·阿方西 / 吉尔·巴罗尼 / 马西莫·比安奇 / 恩尼奥·孔萨尔维 / 吉安卡尔洛·科森蒂诺 / 阿伦·克雷格 / 汉尼斯·赫尔曼 / 弗兰科·梅斯科利尼 / 安东尼奥·普雷斯特 / 吉娜·诺维勒 / 理查德·塞梅尔 / 安德烈提多娜 / 迪尔克·范登贝格 / 奥梅罗·安东努蒂
类型: 剧情 / 喜剧 / 爱情 / 战争
制片国家/地区: 意大利
语言: 意大利语 / 德语 / 英语
上映日期: 2020-01-03(中国大陆) / 1997-12-20(意大利)
片长: 116分钟(国际版) / 125分钟
又名: 一个快乐的传说(港) / Life Is Beautiful
IMDb: tt0118799
豆瓣评分
引用
9.6
1261879人评价
5星
80.6%
4星
16.9%
3星
2.2%
2星
0.2%
1星
0.1%
好友评分
你关注的人看过这部作品的平均分
9.5
4人评价
好于 99% 战争片
好于 99% 爱情片
我看过这部电影 2020-07-12 修改
我的评价:
推荐

## 美丽人生的剧情简介 · · · · · ·

犹太青年圭多（罗伯托·贝尼尼）邂逅美丽的女教师多拉（尼可莱塔·布拉斯基），他彬彬有礼的向多拉鞠躬：“早安！公主！”。历经诸多令人啼笑皆非的周折后，天遂人愿，两人幸福美满的生活在一起。
然而好景不长，法西斯政权下，圭多和儿子被强行送往犹太人集中营。多拉虽没有犹太血统，毅然同行，与丈夫儿子分开关押在一个集中营里。聪明乐天的圭多哄骗儿子这只是一场游戏，奖品就是一辆大坦克，儿子快乐、天真的生活在纳粹的阴霾之中。尽管集中营的生活艰苦寂寞，圭多仍然带给他人很多快乐，他还趁机在纳粹的广播里问候妻子：“早安！公主！”
法西斯政权即将倾覆，纳粹的集中营很快就要接受最后的清理，圭多编给儿子的游戏该怎么结束？他们一家能否平安的度过这黑暗的年代呢？ ©豆瓣

## 美丽人生的演职员 · · · · · · ( 全部 41 )

- 罗伯托·贝尼尼 导演
- 罗伯托·贝尼尼 饰 Guido
- 尼可莱塔·布拉斯基 饰 Dora
- 乔治·坎塔里尼 饰 Giosuè
- 朱斯蒂诺·杜拉诺 饰 Zio
- 赛尔乔·比尼·布斯特里克 饰 Ferruccio

## 美丽人生的视频和图片 · · · · · · ( 预告片5 | 添加视频评论 | 图片889 · 添加 )

## 美丽人生的获奖情况 · · · · · · ( 全部 )

- 第71届奥斯卡金像奖
- 最佳影片(提名)
- 艾尔达·法瑞 / 吉安路易吉·布拉斯基

- 第51届戛纳电影节
- 主竞赛单元 金棕榈奖(提名)
- 罗伯托·贝尼尼

- 第23届日本电影学院奖
- 最佳外语片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  辛德勒的名单

  穿条纹睡衣的男孩

  拯救大兵瑞恩

  钢琴家

  1917

  血战钢锯岭

  乱世佳人

  敦刻尔克

  波斯语课

  罗马假日

我要写短评

## 美丽人生的短评 · · · · · · ( 全部 277092 条 )

热门 / 最新 / 好友

### 26883 有用 不靠谱小姐 看过 2010-08-17 11:39:02

我以为如此智慧的一个人，在那几声枪响过后，必定是会走出来，继续对他的公主说早安的...

### 12754 有用 老鸡｜扶立 看过 2008-01-10 16:54:36

如果谎言可以这样美丽，我也情愿生活在谎言之中

### 8702 有用 UrthónaD'Mors 看过 2008-01-27 23:20:12

喜剧的开始，悲剧的结束， 满满的亲情，无限的父爱

### 1280 有用 长别离 看过 2009-03-13 21:23:18

在真实的历史面前，不可能有这样的轻松与浪漫！

### 13318 有用 monotonous 看过 2007-12-21 16:05:17

人生，就是喜剧，就是一场1000分的游戏。千万别哭，不然那个迈着正步去赴死的犹太人会笑话你的。

> 更多短评 277092条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。

### 0 有用 CoCo陶可可 看过 2021-02-11 13:33:10

2021，008。小男孩的眼睛很出戏，很清澈的感觉，不知道是演出来的，还是就是这样

### 0 有用 LLudeer 看过 2013-12-15 15:37:31

人生就是场美丽的游戏，有爱就是赢家~高中时看过的片子~

我要写影评

## 美丽人生的影评 · · · · · · ( 全部 5279 条 )

热门 / 最新 / 好友
小隐隐于浆糊 2008-03-24 21:11:06

## H4传说

林语堂给人生列出了几个公式： 1)Reality — Dreams ＝ Animal Being 2)Reality ＋ Dreams ＝A heartache(usually called Idealism) 3)Reality ＋ Humor ＝ Realism(also called Conservatism) 4)Dreams － Humor ＝ Fanaticism 5)Dreams ＋ Humor ＝ Fantasy 6)Reality ＋ Dre... (展开)
6800 199 279回应 收起
赛宁 2006-03-05 23:32:27

## “观碟不语”之《美丽人生》

就算在最艰难最黑暗的日子里，就算了无希望，死亡近在眼前，他依然深爱着并用生命与智慧保护着他的妻子与儿子。他的勇气与智慧，即使在战争的硝烟弥漫中，即使在集中营的暗无天日中，即使在最后枪声响起死亡来临的那一刻，依然闪现着耀眼夺目的光芒。 他用尽全力，在集中营的悲... (展开)
5228 158 289回应 收起
徐晋 2005-11-25 23:13:35

## 我们有资格做父亲吗？

生于70年代中末期的我们到了应该可以做父亲的年纪了，在这样一个滑稽的让人绝望的年代里。 我们的经历比任何人都更加动荡：之前的60年代绝大多数还是在故乡发展；之后的80年代刚开始迷惘。而我们这代人是一个开始。 当结束十几年的教育之后，突然发现我们跟体制其实没什么关系... (展开)
2917 476 437回应 收起
Seeking 2009-06-30 01:47:34

## 对《La Vita è Bella》中德国医生和基多说的最后一个谜语的理解

我也看了些国外的评论，基本观点是那就是个普通的谜语，没有什么隐藏的含义，因此我把百度美丽人生吧的一篇帖子转到了这里 导演本人在被问到这个问题时的回答是，这个谜语没有解，目的是为反映那场战争的荒谬。因此大家的争论可以告一段落了。 http://tieba.baidu.com/f?kz... (展开)
2514 158 321回应 收起
crow 2008-12-29 17:04:55

## 该是男人婚前必看的影片

草草看过其他人的影评，满满一片国旗的星星数 倘若谁再挑出这片的毛病 只怕对不起的就是人生二字了 —————————————————————— 很多年前读过一本哲理小册子里讲到过这个故事 那时候还小，不懂得亲情和爱情的伟大 在我不相信谎言的时候，心想这小孩子真好骗 ... (展开)
2138 85 101回应 收起
朝暮雪 2020-01-04 15:35:44

## 伟大喜剧的内核都是悲剧

这篇影评可能有剧透

继《龙猫》《千与千寻》《海上钢琴师》后，《美丽人生》4K修复版也在中国上映了。 2001年2月，《美丽人生》曾在中国上映，但是规模很小。 这次则是大规模上映，而且还是4K修复版。 上小学的时候，学校放了这部电影，当时以为这只是一部喜剧片。 长大以后才明白，这部电影和其它... (展开)
1587 18 57回应 收起
王挣扎 2008-07-20 16:49:36

## 早上好，我的公主！

这篇影评可能有剧透

生活是美丽的，无论它怎样不尽如人意。你会在不经意的时候偶遇可爱的女孩儿，你要对她说：早上好，我的公主！然后脱帽致意，向她展示你的无与伦比的才华。 对任何事情充满巨大的热情，把任何事情都看作天赐，对所有人报以微笑，对欣赏你的人充满敬意。公主怎么会不爱上你... (展开)
1248 92 161回应 收起
硕大无朋 2008-02-23 03:37:05

## 生活不完美却仍旧很美

刚看完美丽人生，哭得稀里哗啦。我看电视电影一般不怎么被感动，因为现在充斥荧屏的所谓催人泪下的故事要么是费尽千辛万苦才在一起的男女主人公其中一个身患绝症而亡的韩剧，要么是单亲家长含辛茹苦养大非亲生儿女而其亲生父亲或母亲在孩子长成之后又突然出现产生各种纠葛的逻... (展开)
661 45 148回应 收起
Emil 2007-10-22 01:24:04

## Buono giorno, Principessa!

这篇影评可能有剧透

说一些细节： 1. 影片一开始就揶揄了一把Nazi：Guido和Ferruccio的车因为刹车失灵冲下山，车窗被植物挡住，Guido就站起来挥手示意人群让开，那个挥手的动作就是Nazi的军礼，也因此他们才被当成是来视察的高官。 2. 我以前老把“Principessa”记成“Princepessa”，这把看... (展开)
402 41 67回应 收起
不散 2020-01-04 18:59:55

## 跨越23年的经典，背后还有这些不为人知的事

本世纪的20年代还没过上几天，我们却要开始怀旧了。 《美丽人生》，豆瓣上这部影片的上映日期让我感触颇深，1997到2020年，基本能算个90后的青年了。 然而这并不是它首次引入内地，其实2001年3月《美丽人生》就曾在内地上映，而这一次全国公映的是本片的“4K修复版”，他们甚至... (展开)
315 1 16回应 收起

> 更多影评 5279篇

添加新讨论

## 讨论区 · · · · · ·

不能理解为什么评价这么高 | 来自人生如茶 | 4 回应 | 2022-11-22 21:08:33
我真心觉得这是影史最被高估的电影 | 来自蝙蝠卫 | 34 回应 | 2022-11-22 21:03:20
原来25年前就已经暗示，拥有绿马才能拥有美丽人生 | 来自萨菲娜 | 17 回应 | 2022-11-22 09:57:46
好的电影，能治愈人生 | 来自塞纳河de候鸟 |  | 2022-11-20 15:06:00
父亲被枪毙前为什么不跑？呜呜呜 | 来自豆友201542393 | 19 回应 | 2022-11-19 19:30:41

> 去这部影片的讨论区（全部1024条）

## 关于《美丽人生》的问题 · · · · · · ( 全部45个 )

- 圭多带乔舒亚大胆的使用德军广播，难道没有被德军察觉？ 7人回答
- 为什么“做爱”可以很直白地说出来？ 18人回答

> 全部45个问题

## 在哪儿看这部电影 · · · · · ·

报错

- 腾讯视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【内牛满面】 (影志)
- 【励志电影】 (影志)
- 那些牛叉闪闪的片子 (家庭种菜笔记)
- 入选《第十放映室》影片之国外篇Ⅰ (心之旋影)

## 谁在看这部电影 · · · · · ·

- 豆友uskeYz5ECg
  1分钟前 想看
- 千层度
  3分钟前 看过
- Murphy's law
  4分钟前 想看

2053910人看过 / 653815人想看

订阅美丽人生的评论:
feed: rss 2.0